function [y,h] = cntobj(ax, objtype)
%CNTOBJ Count a user-specified axes object.
%       [Y] = CNTOBJ(AX) counts the number of objects
%       in the axes specified with the handle H.
%
%       [Y] = CNTOBJ counts the number of desired objects
%       in the current axes.
%
%       [Y,H] = CNTOBJ(AX) and [Y,H] = CNTOBJ return a
%       vector containing the specified object type handles in h.
%
%       See also FIGURE, AXES

%       Dennis W. Brown 1-10-94
%       Copyright (c) 1994 by Dennis W. Brown
%       May be freely distributed.
%       Not for use in commercial products.

% default
if nargin == 0, ax = gca; end;
if nargin < 2,  objtype = 'line'; end

gf = get(ax,'Parent');

% check validity of handle given
if isempty(find(get(gf,'Children') == ax)),
    error('cnttext: Invalid axes handle...');
end

% output variables
y = 0;
h = [];

% find text objects
c = get(ax,'Children');
for i = 1:length(c),
    if strcmp(get(c(i),'Type'),objtype)
       y = y + 1;
       if nargout == 2, h = [h ; c(i)];end;
    end
end;

